@@ -79,7 +79,7 @@ class MetaService:
         if req.status_code != 200:
             raise Exception("Metadata query error: ", path)
 
-        return req.body()
+        return req.text
 
     def query_meta(self, path):
         """ query a path from the meta-data namespace
